import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:videosdk/participant.dart';
import 'package:videosdk/src/features/me/bloc/me_bloc.dart';
import 'package:videosdk/src/features/peers/enitity/peer.dart';
import 'package:videosdk/src/features/signaling/room_client_repository.dart';
import 'package:events2/events2.dart';

class Meeting {
  final BuildContext context;
  late final EventEmitter _eventEmitter;

  Meeting(this.context) {
    this.localParticipant = new Participant(
      context,
      context.read<MeBloc>().state.id,
      context.read<MeBloc>().state.displayName,
    );

    this._eventEmitter = context.read<RoomClientRepository>().eventEmitter;

    this.participants = new Map();

    context.read<RoomClientRepository>().onMeetingJoined =
        (roomClientRepository) {
      // on meeting joined
    };

    _eventEmitter.on("peers-bloc-participant-joined", (Peer newPeer) {
      final newParticipant =
          new Participant(context, newPeer.id, newPeer.displayName);
      participants[newPeer.id] = newParticipant;
      _eventEmitter.emit('participant-joined', newParticipant);
    });

    _eventEmitter.on("peers-bloc-participant-left", (peerId) {
      participants.remove(peerId);
      _eventEmitter.emit('participant-left', peerId);
    });
  }

  late Participant localParticipant;

  late Map<String, Participant> participants;

  void disableWebcam() {
    context.read<RoomClientRepository>().disableWebcam();
  }

  void enableWebcam() {
    context.read<RoomClientRepository>().enableWebcam();
  }

  void disableMic() {
    context.read<RoomClientRepository>().disableMic();
  }

  void enableMic() {
    context.read<RoomClientRepository>().enableMic();
  }

  void join() {
    context.read<RoomClientRepository>().join();
  }

  void leave() {
    context.read<RoomClientRepository>().close();
  }

  on(String event, Function handler) {
    this._eventEmitter.on(event, handler);
  }
}
