import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_webrtc/flutter_webrtc.dart';
import 'package:videosdk/src/features/signaling/room_client_repository.dart';
import 'package:events2/events2.dart';
import 'package:videosdk/stream.dart';

class Participant {
  final BuildContext context;
  late final EventEmitter _participantEventEmitter;
  late final EventEmitter _eventEmitter;

  late String id;
  late String displayName;
  late Stream stream;
  late Map<String, Stream> streams;

  RTCVideoRenderer? renderer;

  Participant(this.context, this.id, this.displayName) {
    this._participantEventEmitter = new EventEmitter();
    this.streams = new Map();

    this._eventEmitter = context.read<RoomClientRepository>().eventEmitter;

    this._eventEmitter.on(
      "stream-enabled-$id",
      (data) {
        if (data['audio'] != null) {
          final consumer = data["audio"];
          final Stream newStream = new Stream(
            context: this.context,
            consumer: consumer,
          );

          this._addconsumer(newStream);
        } else if (data["renderer"] != null && data["video"] != null) {
          final consumer = data["video"];
          final renderer = data["renderer"];

          final Stream newStream = new Stream(
            context: this.context,
            consumer: consumer,
            renderer: renderer,
          );

          this._addconsumer(newStream);
        }
      },
    );

    this._eventEmitter.on(
      "stream-disabled-$id",
      (data) {
        if (data['audioConsumerId'] != null) {
          final consumerId = data['audioConsumerId'];
          this._removeConsumer(consumerId);
        } else if (data["renderer"] != null &&
            data["videoConsumerId"] != null) {
          final consumerId = data['videoConsumerId'];
          this._removeConsumer(consumerId);
        }
      },
    );
  }

  on(event, handler) {
    this._participantEventEmitter.on(event, handler);
  }

  _addconsumer(Stream stream) {
    streams[stream.id] = stream;

    this._participantEventEmitter.emit(
          "stream-enabled",
          stream,
        );
  }

  _removeConsumer(String consumerId) {
    final Stream? streamToRemove = streams[consumerId];

    if (streamToRemove != null) {
      streams.remove(consumerId);

      this._participantEventEmitter.emit(
            "stream-disabled",
            streamToRemove,
          );
    }
  }
}
